==> com.liferay.source.formatter-1.0.581-sources-commercial.jar: com/liferay/source/formatter/checks/GradleBodyCheck.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.source.formatter.checks;

import com.liferay.petra.string.StringPool;
import com.liferay.portal.kernel.util.StringBundler;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.source.formatter.parser.GradleFile;

import java.util.Set;
import java.util.TreeSet;

/**
 * @author Peter Shin
 */
public class GradleBodyCheck extends BaseGradleFileCheck {

	@Override
	protected String doProcess(
			String fileName, String absolutePath, GradleFile gradleFile,
			String content)
		throws Exception {

		if (absolutePath.contains("/project-templates-")) {
			return content;
		}

		String bodyBlock = gradleFile.getBodyBlock();

		if (Validator.isNull(bodyBlock)) {
			return content;
		}

		String newBlock = StringPool.BLANK;
		Set<String> newBlocks = new TreeSet<>();
		String oldBlocks = StringPool.BLANK;

		for (String line : StringUtil.splitLines(bodyBlock)) {
			if (line.matches(
					"(allprojects|project|subprojects|(else|for|if|while)\\s)" +
						".*\\{")) {

				return content;
			}

			if (Validator.isNull(newBlock) && line.matches("\\w+\\s*\\{")) {
				newBlock = line;
				oldBlocks = oldBlocks + "\n" + line;

				continue;
			}

			if (Validator.isNotNull(newBlock) && !newBlock.endsWith("\n}")) {
				newBlock = newBlock + "\n" + line;
				oldBlocks = oldBlocks + "\n" + line;

				if (newBlock.endsWith("\n}")) {
					newBlocks.add(newBlock);

					newBlock = StringPool.BLANK;
				}

				continue;
			}

			oldBlocks = oldBlocks + "\n" + line;

			if (Validator.isNotNull(line)) {
				newBlocks.clear();
				oldBlocks = StringPool.BLANK;
			}
		}

		if (newBlocks.isEmpty()) {
			return content;
		}

		StringBundler sb = new StringBundler(2 * newBlocks.size());

		for (String s : newBlocks) {
			sb.append(s);
			sb.append("\n\n");
		}

		sb.setIndex(sb.index() - 1);

		return StringUtil.replaceLast(
			content, StringUtil.trim(oldBlocks), sb.toString());
	}

}

==> com.liferay.source.formatter-1.0.1177-sources-commercial.jar: com/liferay/source/formatter/checks/GradleBodyCheck.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.source.formatter.checks;

import com.liferay.petra.string.StringBundler;
import com.liferay.petra.string.StringPool;
import com.liferay.portal.kernel.util.StringUtil;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.source.formatter.parser.GradleFile;

import java.util.Set;
import java.util.TreeSet;

/**
 * @author Peter Shin
 */
public class GradleBodyCheck extends BaseGradleFileCheck {

	@Override
	protected String doProcess(
		String fileName, String absolutePath, GradleFile gradleFile,
		String content) {

		if (absolutePath.contains("/project-templates-")) {
			return content;
		}

		String bodyBlock = gradleFile.getBodyBlock();

		if (Validator.isNull(bodyBlock)) {
			return content;
		}

		String newBlock = StringPool.BLANK;
		Set<String> newBlocks = new TreeSet<>();
		String oldBlocks = StringPool.BLANK;

		for (String line : StringUtil.splitLines(bodyBlock)) {
			if (line.matches(
					"(allprojects|project|subprojects|(else|for|if|while)\\s)" +
						".*\\{")) {

				return content;
			}

			if (Validator.isNull(newBlock) && line.matches("\\w+\\s*\\{")) {
				newBlock = line;
				oldBlocks = oldBlocks + "\n" + line;

				continue;
			}

			if (Validator.isNotNull(newBlock) && !newBlock.endsWith("\n}")) {
				newBlock = newBlock + "\n" + line;
				oldBlocks = oldBlocks + "\n" + line;

				if (newBlock.endsWith("\n}")) {
					newBlocks.add(newBlock);

					newBlock = StringPool.BLANK;
				}

				continue;
			}

			oldBlocks = oldBlocks + "\n" + line;

			if (Validator.isNotNull(line)) {
				newBlocks.clear();
				oldBlocks = StringPool.BLANK;
			}
		}

		if (newBlocks.isEmpty()) {
			return content;
		}

		StringBundler sb = new StringBundler(2 * newBlocks.size());

		for (String s : newBlocks) {
			sb.append(s);
			sb.append("\n\n");
		}

		sb.setIndex(sb.index() - 1);

		return StringUtil.replaceLast(
			content, StringUtil.trim(oldBlocks), sb.toString());
	}

}
